| trace | R Documentation |
Compute the left or right trace of an endorelation.
relation_trace(x, which)
x |
an endorelation. |
which |
one of |
Let R be a crisp endorelation. The left and right trace of
R contain all pairs x, y for which z R x implies
z R y for all z (left trace) or y R z implies
x R z for all z (right trace), respectively. These are
the largest (in the natural ordering of relations with the same
domain) relations such that R * S \le R or S * R \le R,
respectively (where * denotes composition). In the fuzzy case,
the memberships of the traces can be defined as the infima over the
corresponding fuzzy membership implications.
See Chapter 2.3 in \bibcitetFodor+Roubens:1994 for more information.
Fodor+Roubens:1994
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.